Set routines
============

.. currentmodule:: numpy

.. autosummary::
   :toctree: generated/

   lib.arraysetops

Making proper sets
------------------
.. autosummary::
   :toctree: generated/

   unique

Boolean operations
------------------
.. autosummary::
   :toctree: generated/

   in1d
   intersect1d
   isin
   setdiff1d
   setxor1d
   union1d
